@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2019-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2019-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino_xl.lib.orders.models import *
 from lino.api import _
@@ -17,6 +17,16 @@ VoucherTypes.add_item_lazy(TraOrdersByJournal)
 
 
 class Order(Order):
+
+    class Meta(Order.Meta):
+        abstract = dd.is_abstract_model(__name__, 'Order')
+
+    # def get_invoice_recipient(self):
+    #     return self.project
+
+    # def get_invoicing_area(self):
+    #     return self.journal.room.invoicing_area
+
     def get_worker_choices(self):
         Worker = dd.resolve_model(dd.plugins.orders.worker_model)
         if self.journal.room:
