@@ -1,13 +1,16 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2018-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2018-2022 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino.projects.std.settings import *
 from lino.api import _
+from lino_presto import SETUP_INFO
 
 class Site(Site):
     verbose_name = "Lino Presto"
-    url = "http://presto.lino-framework.org"
+    description = SETUP_INFO['description']
+    version = SETUP_INFO['version']
+    url = SETUP_INFO['url']
 
     # demo_fixtures = 'std demo minimal_ledger euvatrates demo_bookings payments demo2'.split()
     # demo_fixtures = 'std demo minimal_ledger demo_bookings payments demo2'.split()
@@ -25,13 +28,14 @@ class Site(Site):
     auto_configure_logger_names = "atelier django lino lino_xl lino_presto"
     default_build_method = 'weasy2pdf'
     textfield_bleached = True
+    default_ui = 'lino_react.react'  # calview is better in react than in extjs
 
     def get_installed_apps(self):
-        yield super(Site, self).get_installed_apps()
+        yield super().get_installed_apps()
         # yield 'lino.modlib.gfks'
         yield 'lino_presto.lib.users'
         yield 'lino_presto.lib.contacts'
-        yield 'lino.modlib.uploads'
+        yield 'lino_xl.lib.uploads'
         yield 'lino_presto.lib.cal'
         yield 'lino_presto.lib.ledger'
         yield 'lino_presto.lib.orders'
@@ -51,7 +55,7 @@ class Site(Site):
         yield 'lino_presto.lib.products'
         yield 'lino_presto.lib.sales'
         # yield 'lino_xl.lib.vat'
-        yield 'lino_presto.lib.invoicing'
+        yield 'lino_xl.lib.invoicing'
 
         yield 'lino_xl.lib.sepa'
         # yield 'lino_xl.lib.finan'
@@ -68,11 +72,12 @@ class Site(Site):
         yield 'lino.modlib.checkdata'
         yield 'lino.modlib.tinymce'
         yield 'lino.modlib.weasyprint'
+        yield 'lino.modlib.help'
 
         yield 'lino_presto.lib.presto'
 
     def get_plugin_configs(self):
-        yield super(Site, self).get_plugin_configs()
+        yield super().get_plugin_configs()
         yield ('healthcare', 'client_model', 'presto.Client')
         yield ('topics', 'menu_group', 'contacts')
         yield ('countries', 'country_code', 'BE')
@@ -80,19 +85,19 @@ class Site(Site):
         yield ('clients', 'menu_group', 'contacts')
         yield ('orders', 'worker_model', 'contacts.Worker')
         # yield ('ledger', 'purchase_stories', False)
-        yield ('ledger', 'sales_stories', False)
+        yield ('ledger', 'sales_method', None)
         # yield ('cal', 'default_guest_state', 'invited')
         yield ('calview', 'params_layout', "state project project__municipality event_type room")
+        yield ('clients', 'demo_coach', 'martha')
+        yield ('invoicing', 'order_model', 'orders.Order')
 
     def setup_quicklinks(self, user, tb):
-        super(Site, self).setup_quicklinks(user, tb)
+        super().setup_quicklinks(user, tb)
         tb.add_action(self.models.contacts.Workers)
         tb.add_action(self.models.presto.Clients)
         # for a in (self.models.calview.WeeklyView, self.models.contacts.WeeklyView):
         #     tb.add_instance_action(
         #         a.get_row_by_pk(None, "0"), action=a.default_action, label=a.label)
 
-        for p in self.models.calview.Planners.get_list_items():
-            a = p.weekly_view
-            tb.add_instance_action(
-                a.get_row_by_pk(None, "0"), action=a.default_action, label=p.text)
+            # tb.add_instance_action(
+            #     a.get_row_by_pk(None, "0"), action=a.default_action, label=p.text)
