@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2015-2022 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 # Note that this module may not have a docstring because any
 # global variable defined here will override the global
@@ -13,16 +13,16 @@
 
 SETUP_INFO = dict(
     name='lino_presto',
-    version='20.7.0',
+    version='22.12.1',
     install_requires=['lino_xl'],
     tests_require=['bleach'],
-    description="A Lino application for managing services",
-    license='BSD-2-Clause',
+    description="A Lino for managing services",
+    license_files=['COPYING'],
     include_package_data=True,
     zip_safe=False,
-    author='Luc Saffre',
-    author_email='luc.saffre@gmail.com',
-    url="http://presto.lino-framework.org",
+    author='Rumma & Ko Ltd',
+    author_email='info@lino-framework.org',
+    url="https://gitlab.com/lino-framework/presto",
     #~ test_suite = 'lino.test_apps',
     test_suite='tests',
     classifiers="""\
@@ -33,7 +33,7 @@ SETUP_INFO = dict(
   Framework :: Django
   Intended Audience :: Developers
   Intended Audience :: System Administrators
-  License :: OSI Approved :: BSD License
+  License :: OSI Approved :: GNU Affero General Public License v3
   Natural Language :: English
   Natural Language :: French
   Natural Language :: German
@@ -45,21 +45,19 @@ SETUP_INFO = dict(
 SETUP_INFO.update(long_description="""\
 
 Lino Presto is an application for managing services with physical on-site
-presence of the workers.  Services can be individually scheduled or recurring
-calendar entries based on contracts.  Integrated calendar and contacts.
-Automatically generate invoices based on calendar entries.   Optional
-functionalities include accounting (payments, purchases, general ledger, VAT
-declarations).
+presence of the workers.  Deployments can be either individually scheduled or
+recurring based on contracts.  Integrated calendar and contacts. Automatically
+generate invoices based on calendar entries.   Optional functionalities include
+accounting (payments, purchases, general ledger, VAT declarations).
 
-- The central project homepage is http://presto.lino-framework.org
+- Project homepage: http://presto.lino-framework.org
 
-- German documentation is at http://de.presto.lino-framework.org/
+- Documentation: https://lino-framework.gitlab.io/presto/
 
-- For *introductions* and *commercial information* about Lino Presto
-  see http://www.saffre-rumma.net
+- Commercial information: https://www.saffre-rumma.net
 
 The name "Presto" originally comes from "prestations de service", the French
-expression for service providements.  It also means "quick" in Italian.
+expression for service providement.  It also means "quick" in Italian.
 
 """)
 
@@ -101,4 +99,5 @@ SETUP_INFO.update(message_extractors={
     ],
 })
 
-SETUP_INFO.update(package_data=dict())
+# SETUP_INFO.update(package_data=dict())
+SETUP_INFO.update(include_package_data=True)
